#
# spec file for package python-pyclipper
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2020 Xu Zhao (i@xuzhao.net).
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
Name:           python-pyclipper
Version:        1.3.0.post5
Release:        1.1
Summary:        Cython wrapper for the Clipper library for clipping lines and polygons
License:        MIT
URL:            https://github.com/fonttools/pyclipper
Source:         https://files.pythonhosted.org/packages/source/p/pyclipper/pyclipper-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
%python_subpackages

%description
Pyclipper is a Cython wrapper exposing public functions and classes of
the C++ translation of the `Angus Johnson's Clipper library`, a library
for clipping and offsetting lines and polygons.

The Clipper library performs line & polygon clipping - intersection,
union, difference & exclusive-or, and line & polygon offsetting. The
library is based on Vatti's clipping algorithm.

%prep
%setup -q -n pyclipper-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest_arch

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/pyclipper
%{python_sitearch}/pyclipper-%{version}*-info

%changelog
* Sun Dec 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.0.post5:
  * Build Python 3.12 wheels. No code changes.
* Wed May 10 2023 Dirk Müller <dmueller@suse.com>
- remove obsolete setuptools_scm_git_archive requirements
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.3.0.post4
  * Build Python 3.11 wheels. No code changes.
* Wed Oct  5 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.3.0.post3
  Rebuild pre-generated cython sources in sdist package to fix build issue on Python 3.11.0 beta1
* Fri Jan 14 2022 Ben Greiner <code@bnavigator.de>
- Extend package description
- Remove python2 workarounds
* Thu Jan 13 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.3.0post2
  * Export pyclipper.__version__ string (#40).
  * Removed long-deprecated SCALING_FACTOR global variable.
- Relese 1.2.0
  * Release the Global Interpreter Lock (GIL) while doing more CPU
    intensive calls to ClipperLib (union, difference, intersection,
    minkowski, offset, etc), to allow Python apps to better
    parallelize when using threading (#29, #30).
- Drop python-pyclipper-no-unittest2.patch
* Wed Jun 10 2020 Matej Cepl <mcepl@suse.com>
- Explain necessity of unittest2 for python2
* Tue Jun  2 2020 pgajdos@suse.com
- drop dependency on unittest2 for python3
- added patches
  https://github.com/fonttools/pyclipper/pull/32
  + python-pyclipper-no-unittest2.patch
* Fri Mar  6 2020 Xu Zhao <i@xuzhao.net>
- Initial commit.
